@@ -3,7 +3,7 @@ BEGIN {
   $POE::Quickie::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $POE::Quickie::VERSION = '0.12';
+  $POE::Quickie::VERSION = '0.13';
 }
 
 use strict;
@@ -187,7 +187,7 @@ sub _child_signal {
     delete $self->{wheels}{$id};
 
     if (defined $event) {
-        $kernel->post(
+        $kernel->call(
             $self->{parent_id},
             $event,
             $status,
@@ -233,7 +233,7 @@ sub _child_stdout {
     }
     elsif (defined (my $event = $self->{wheels}{$id}{args}{StdoutEvent})) {
         my $context = $self->{wheels}{$id}{args}{Context};
-        $kernel->post(
+        $kernel->call(
             $self->{parent_id},
             $event,
             $output,
@@ -269,7 +269,7 @@ sub _child_stderr {
     }
     elsif (defined (my $event = $self->{wheels}{$id}{args}{StderrEvent})) {
         my $context = $self->{wheels}{$id}{args}{Context};
-        $kernel->post(
+        $kernel->call(
             $self->{parent_id},
             $event,
             $error,
